@@ -102,12 +102,7 @@ class App:
 
         self.collections = []
 
-        self.server = Server(
-            bind_addr=(self.host, self.port),
-            wsgi_app=self,
-            request_queue_size=500,
-            server_name=socket.gethostname()
-        )
+
 
 
     def wsgi_app(self, environ, start_response):
